@@ -2,8 +2,8 @@
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: persistent-sqlite
 version: 2.2.1
-id: persistent-sqlite-2.2.1-b56b33e12d6a3022823671225fb79694
-key: persi_7if2GxT88lgE9rDaV6LKo7
+id: persistent-sqlite-2.2.1-13e92ec43d8fdb90ec4310a06ff434fd
+key: persi_LlPPMePSYPd6EU3ZiKLlrS
 license: MIT
 maintainer: Michael Snoyman <michael@snoyman.com>
 stability: Stable
@@ -20,19 +20,19 @@ trusted: False
 import-dirs: /usr/lib/ghc-7.10.3/site-local/persistent-sqlite-2.2.1
 library-dirs: /usr/lib/ghc-7.10.3/site-local/persistent-sqlite-2.2.1
 data-dir: /usr/share/arm-linux-ghc-7.10.3/persistent-sqlite-2.2.1
-hs-libraries: HSpersistent-sqlite-2.2.1-7if2GxT88lgE9rDaV6LKo7
+hs-libraries: HSpersistent-sqlite-2.2.1-LlPPMePSYPd6EU3ZiKLlrS
 extra-libraries:
     pthread
 depends:
-    aeson-0.11.1.0-01f93b6d659087121e16b9df8deda57c
+    aeson-0.11.1.1-0413068b3d94ca1008e286bfe7fa084f
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
     bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
-    conduit-1.2.6.3-0e2837c15036cd2e0c379e7f893dd487
+    conduit-1.2.6.4-0dfd87f475e845002478c37d3a30df1e
     containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
     monad-control-1.0.0.5-237b0aabd7893e5e3f4b9224e05c849c
-    monad-logger-0.3.18-cd8d51c949646894888975572eea97f1
+    monad-logger-0.3.18-7704b739a8ba950a4b62906c3ab56228
     old-locale-1.0.0.7-5aedb410aa2e5fddd3c57e9b4de1f46a
-    persistent-2.2.4.1-2b50a3e9b6124bb06f6361c04fb03b63
+    persistent-2.2.4.1-550ce3a441e5dfee4f5236d6597d598b
     resourcet-1.1.7.3-3e7ca03abacc332d28328c69bbd74cd4
     text-1.2.2.0-2f82ea4adfdd656d9a8840ad2ee17cc0
     time-1.5.0.1-cf94b0d806e26f6c4e356671290061b2
